# -*- coding: utf-8 -*-
# Copyright (c) 2015, Vispy Development Team.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

from .clipper import Clipper  # noqa
from .color import Alpha, ColorFilter, IsolineFilter, ZColormapFilter  # noqa
from .picking import PickingFilter  # noqa
